@@ -31,12 +31,9 @@ from Globals import PersistentMapping
 class TestBibtexParsing(PloneTestCase.PloneTestCase):
     """
     """
-    
+
     def afterSetUp(self):
         self._refreshSkinData()
-        #self.bf = self.getEmptyBibFolder()
-        #bib_source = open(setup.BIBTEX_TEST_BIB, 'r').read()
-        #self.bf.processImport(bib_source, 'bibtex_test.bib')
 
     def testBibtexAuthorParsing(self):
         bibtool = self.portal.portal_bibliography
@@ -64,18 +61,18 @@ class TestBibtexParsing(PloneTestCase.PloneTestCase):
         bibtool = self.portal.portal_bibliography
         p = bibtool.getParser('bibtex')
         source = open(setup.BIBTEX_TEST_INBOOKREFERENCES, 'r').read()
-	ref = {
-	    'booktitle': 'In einem fiktiven Buch vor unserer Zeit',
-	    'title': 'Die Tage der Ankunft',
-	    'chapter': 'Die Tage der Ankunft',
-	    'publication_url': 'http://www.sunweavers.net/',
-	}
+        ref = {
+            'booktitle': 'In einem fiktiven Buch vor unserer Zeit',
+            'title': 'Die Tage der Ankunft',
+            'chapter': 'Die Tage der Ankunft',
+            'publication_url': 'http://www.sunweavers.net/',
+        }
 
-	source = p.preprocess(source)
-    	result = p.parseEntry(source)
-	
-	for key in ref.keys():
-	    self.failUnless( result.has_key(key) and (ref[key] == result[key]) )
+        source = p.preprocess(source)
+        result = p.parseEntry(source)
+
+        for key in ref.keys():
+            self.failUnless( result.has_key(key) and (ref[key] == result[key]) )
 
     def testAnnoteParsing(self):
         bibtool = self.portal.portal_bibliography
@@ -88,34 +85,34 @@ class TestBibtexParsing(PloneTestCase.PloneTestCase):
         bibtool = self.portal.portal_bibliography
         p = bibtool.getParser('bibtex')
         source = open(setup.BIBTEX_TEST_TYPEFIELD, 'r').read()
-	ref = {
-	    'publication_type': 'Doktorarbeit',
-	    'title': 'Mein Herr Doktor',
-	    'school': 'CAU Kiel',
-	    'institution': 'Ökologie-Zentrum',
-	}
+        ref = {
+            'publication_type': 'Doktorarbeit',
+            'title': 'Mein Herr Doktor',
+            'school': 'CAU Kiel',
+            'institution': 'Ökologie-Zentrum',
+        }
 
-	source = bibtool.checkEncoding(source)
-	source = p.preprocess(source)
-    	result = p.parseEntry(source)
-	
-	for key in ref.keys():
-	    self.failUnless( result.has_key(key) and (ref[key] == result[key]) )
+        source = bibtool.checkEncoding(source, 'iso-8859-15')
+        source = p.preprocess(source)
+        result = p.parseEntry(source)
+
+        for key in ref.keys():
+            self.failUnless( result.has_key(key) and (ref[key] == result[key]) )
 
     def testBibtexTypeLastFieldTrailingKomma(self):
         bibtool = self.portal.portal_bibliography
         p = bibtool.getParser('bibtex')
         source = open(setup.BIBTEX_TEST_LASTFIELDKOMMA, 'r').read()
 
-	source = bibtool.checkEncoding(source)
-	source = p.preprocess(source)
-	results = p.getEntries(source)
+        source = bibtool.checkEncoding(source, 'iso-8859-15')
+        source = p.preprocess(source)
+        results = p.getEntries(source)
 
-	# the last field in a bibtex entry always had a trailing ","
-	self.failUnless( len(results) == 2  )
-	self.failUnless( results[0]['institution'] == results[1]['institution']  )
-	self.failUnless( results[0]['publication_type'] == results[1]['publication_type']  )
-	self.failUnless( results[0]['publication_type'] == 'Doktorarbeit,,,' )
+        # the last field in a bibtex entry always had a trailing ","
+        self.failUnless( len(results) == 2  )
+        self.failUnless( results[0]['institution'] == results[1]['institution']  )
+        self.failUnless( results[0]['publication_type'] == results[1]['publication_type']  )
+        self.failUnless( results[0]['publication_type'] == 'Doktorarbeit,,,' )
 
 def test_suite():
     from unittest import TestSuite, makeSuite
